<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ActivityResultReceiver</name>
    <message>
        <location filename="../android_rtl_sdr.cpp" line="178"/>
        <source>Android RTL-SDR driver is not installed</source>
        <translation>Android RTL-SDR Treiber ist nicht installiert</translation>
    </message>
</context>
<context>
    <name>AirspySettings</name>
    <message>
        <location filename="../QML/settingpages/AirspySettings.qml" line="12"/>
        <source>Airspy settings</source>
        <translation>Airspy-Einstellungen</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/AirspySettings.qml" line="27"/>
        <source>Enable bias tee</source>
        <translation>Fernspeisung aktivieren</translation>
    </message>
</context>
<context>
    <name>CAndroid_RTL_SDR</name>
    <message>
        <source>Android RTL-SDR driver is not installed</source>
        <translation type="vanished">Android RTL-SDR Treiber ist nicht installiert</translation>
    </message>
    <message>
        <source>Would you like to install it? Start welle.io again after install.</source>
        <translation type="vanished">Soll er installiert werden? welle.io muss nach der Treiberinstallation neu gestartet werden.</translation>
    </message>
    <message>
        <location filename="../android_rtl_sdr.cpp" line="137"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../android_rtl_sdr.cpp" line="138"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../android_rtl_sdr.cpp" line="139"/>
        <source>Android RTL-SDR driver is not installed. Do you would like to install it? After install start welle.io again.</source>
        <translation>Der Android RTL-SDR-Treiber ist nicht installiert. Möchten Sie ihn installieren? Danach bitte welle.io neu starten.</translation>
    </message>
</context>
<context>
    <name>CDABConstants</name>
    <message>
        <source>none</source>
        <translation type="vanished">nicht gesetzt</translation>
    </message>
    <message>
        <source>News</source>
        <translation type="vanished">Nachrichten</translation>
    </message>
    <message>
        <source>Current Affairs</source>
        <translation type="vanished">Aktuelle Nachrichten</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="vanished">Informationen</translation>
    </message>
    <message>
        <source>Sport</source>
        <translation type="vanished">Sport</translation>
    </message>
    <message>
        <source>Education</source>
        <translation type="vanished">Bildung</translation>
    </message>
    <message>
        <source>Drama</source>
        <translation type="vanished">Drama</translation>
    </message>
    <message>
        <source>Arts</source>
        <translation type="vanished">Kunst</translation>
    </message>
    <message>
        <source>Science</source>
        <translation type="vanished">Forschung</translation>
    </message>
    <message>
        <source>Talk</source>
        <translation type="vanished">Talk</translation>
    </message>
    <message>
        <source>Pop Music</source>
        <translation type="vanished">Pop</translation>
    </message>
    <message>
        <source>Rock Music</source>
        <translation type="vanished">Rock</translation>
    </message>
    <message>
        <source>Light classical</source>
        <translation type="vanished">Klassik</translation>
    </message>
    <message>
        <source>Classical Music</source>
        <translation type="vanished">Klassik</translation>
    </message>
    <message>
        <source>Weather</source>
        <translation type="vanished">Wetter</translation>
    </message>
    <message>
        <source>Finance</source>
        <translation type="vanished">Finanzen</translation>
    </message>
    <message>
        <source>Children&apos;s</source>
        <translation type="vanished">Kinder</translation>
    </message>
    <message>
        <source>Religion</source>
        <translation type="vanished">Religion</translation>
    </message>
    <message>
        <source>Travel</source>
        <translation type="vanished">Reise</translation>
    </message>
    <message>
        <source>Leisure</source>
        <translation type="vanished">Freizeit</translation>
    </message>
    <message>
        <source>Jazz and Blues</source>
        <translation type="vanished">Jazz und Blues</translation>
    </message>
    <message>
        <source>Country Music</source>
        <translation type="vanished">Country</translation>
    </message>
    <message>
        <source>Oldies Music</source>
        <translation type="vanished">Oldies</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="vanished">Unbekannt</translation>
    </message>
    <message>
        <source>Albanian</source>
        <translation type="vanished">Albanisch</translation>
    </message>
    <message>
        <source>Breton</source>
        <translation type="vanished">Bretonisch</translation>
    </message>
    <message>
        <source>Catalan</source>
        <translation type="vanished">Katalanisch</translation>
    </message>
    <message>
        <source>Croatian</source>
        <translation type="vanished">Kroatisch</translation>
    </message>
    <message>
        <source>Welsh</source>
        <translation type="vanished">Wallisisch</translation>
    </message>
    <message>
        <source>Czech</source>
        <translation type="vanished">Tschechisch</translation>
    </message>
    <message>
        <source>Danish</source>
        <translation type="vanished">Dänisch</translation>
    </message>
    <message>
        <source>German</source>
        <translation type="vanished">Deutsch</translation>
    </message>
    <message>
        <source>English</source>
        <translation type="vanished">Englisch</translation>
    </message>
    <message>
        <source>Spanish</source>
        <translation type="vanished">Spanisch</translation>
    </message>
    <message>
        <source>Esperanto</source>
        <translation type="vanished">Esperanto</translation>
    </message>
    <message>
        <source>Estonian</source>
        <translation type="vanished">Estnisch</translation>
    </message>
    <message>
        <source>Basque</source>
        <translation type="vanished">Baskisch</translation>
    </message>
    <message>
        <source>Faroese</source>
        <translation type="vanished">Färöisch</translation>
    </message>
    <message>
        <source>French</source>
        <translation type="vanished">Französisch</translation>
    </message>
    <message>
        <source>Frisian</source>
        <translation type="vanished">Friesisch</translation>
    </message>
    <message>
        <source>Irish</source>
        <translation type="vanished">Irisch</translation>
    </message>
    <message>
        <source>Gaelic</source>
        <translation type="vanished">Gälisch</translation>
    </message>
    <message>
        <source>Galician</source>
        <translation type="vanished">Galicisch</translation>
    </message>
    <message>
        <source>Icelandic</source>
        <translation type="vanished">Isländisch</translation>
    </message>
    <message>
        <source>Italian</source>
        <translation type="vanished">Italienisch</translation>
    </message>
    <message>
        <source>Lappish</source>
        <translation type="vanished">Lappisch</translation>
    </message>
    <message>
        <source>Latin</source>
        <translation type="vanished">Latein</translation>
    </message>
    <message>
        <source>Latvian</source>
        <translation type="vanished">Lettisch</translation>
    </message>
    <message>
        <source>Luxembourgian</source>
        <translation type="vanished">Luxemburgisch</translation>
    </message>
    <message>
        <source>Lithuanian</source>
        <translation type="vanished">Litauisch</translation>
    </message>
    <message>
        <source>Hungarian</source>
        <translation type="vanished">Ungarisch</translation>
    </message>
    <message>
        <source>Maltese</source>
        <translation type="vanished">Maltesisch</translation>
    </message>
    <message>
        <source>Dutch</source>
        <translation type="vanished">Niederländisch</translation>
    </message>
    <message>
        <source>Norwegian</source>
        <translation type="vanished">Norwegisch</translation>
    </message>
    <message>
        <source>Occitan</source>
        <translation type="vanished">Okzitanisch</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation type="vanished">Polnisch</translation>
    </message>
    <message>
        <source>Portuguese</source>
        <translation type="vanished">Portugiesisch</translation>
    </message>
    <message>
        <source>Romanian</source>
        <translation type="vanished">Rumänisch</translation>
    </message>
    <message>
        <source>Romansh</source>
        <translation type="vanished">Rätoromanisch</translation>
    </message>
    <message>
        <source>Serbian</source>
        <translation type="vanished">Serbisch</translation>
    </message>
    <message>
        <source>Slovak</source>
        <translation type="vanished">Slowakisch</translation>
    </message>
    <message>
        <source>Slovene</source>
        <translation type="vanished">Slowenisch</translation>
    </message>
    <message>
        <source>Finnish</source>
        <translation type="vanished">Finnisch</translation>
    </message>
    <message>
        <source>Swedish</source>
        <translation type="vanished">Schwedisch</translation>
    </message>
    <message>
        <source>Turkish</source>
        <translation type="vanished">Türkisch</translation>
    </message>
    <message>
        <source>Flemish</source>
        <translation type="vanished">Flämisch</translation>
    </message>
    <message>
        <source>Walloon</source>
        <translation type="vanished">Wallonisch</translation>
    </message>
</context>
<context>
    <name>CGUI</name>
    <message>
        <source>Station list is empty</source>
        <translation type="vanished">Keine Sender vorhanden</translation>
    </message>
    <message>
        <source>version</source>
        <translation type="vanished">Version</translation>
    </message>
    <message>
        <source>Git revision</source>
        <translation type="vanished">Git Revision</translation>
    </message>
    <message>
        <source>Build on</source>
        <translation type="vanished">Übersetzt am</translation>
    </message>
    <message>
        <source>QT version</source>
        <translation type="vanished">QT Version</translation>
    </message>
</context>
<context>
    <name>CGUIHelper</name>
    <message>
        <location filename="../gui_helper.cpp" line="65"/>
        <location filename="../gui_helper.cpp" line="654"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimieren</translation>
    </message>
    <message>
        <location filename="../gui_helper.cpp" line="68"/>
        <location filename="../gui_helper.cpp" line="655"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximieren</translation>
    </message>
    <message>
        <location filename="../gui_helper.cpp" line="71"/>
        <location filename="../gui_helper.cpp" line="656"/>
        <source>&amp;Restore</source>
        <translation>Wiede&amp;rherstellen</translation>
    </message>
    <message>
        <location filename="../gui_helper.cpp" line="74"/>
        <location filename="../gui_helper.cpp" line="657"/>
        <source>&amp;Quit</source>
        <translation>Beenden (&amp;Quit)</translation>
    </message>
    <message>
        <location filename="../gui_helper.cpp" line="127"/>
        <source>version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../gui_helper.cpp" line="128"/>
        <source>Git revision</source>
        <translation>Git-Revision</translation>
    </message>
    <message>
        <location filename="../gui_helper.cpp" line="129"/>
        <source>Build on</source>
        <translation>Übersetzt am</translation>
    </message>
    <message>
        <location filename="../gui_helper.cpp" line="130"/>
        <source>QT version</source>
        <translation>Qt-Version</translation>
    </message>
    <message>
        <location filename="../gui_helper.cpp" line="283"/>
        <source>The program will keep running in the system tray. To terminate the program, choose &lt;b&gt;Quit&lt;/b&gt; in the context menu of the system tray entry.</source>
        <translation>Das Programm bleibt im Hintergrund aktiv. Um es gänzlich zu schließen, wählen Sie &lt;b&gt;Beenden&lt;/b&gt; aus dem Kontextmenü des Icons in der Taskleiste.</translation>
    </message>
    <message>
        <location filename="../gui_helper.cpp" line="776"/>
        <source> (unavailable, fallback to Default)</source>
        <translation> (nicht verfügbar, Rücksetzen auf Standardeinstellung)</translation>
    </message>
    <message>
        <location filename="../gui_helper.cpp" line="780"/>
        <source>Style of system</source>
        <translation>Systemstil</translation>
    </message>
    <message>
        <location filename="../gui_helper.cpp" line="782"/>
        <source> (Recommended)</source>
        <translation> (empfohlen)</translation>
    </message>
</context>
<context>
    <name>CRadioController</name>
    <message>
        <location filename="../radio_controller.cpp" line="608"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location filename="../radio_controller.cpp" line="406"/>
        <location filename="../radio_controller.cpp" line="627"/>
        <source>No Station</source>
        <translation>Kein Sender gewählt</translation>
    </message>
    <message>
        <location filename="../radio_controller.cpp" line="152"/>
        <source>Error while opening file </source>
        <translation>Fehler beim Öffnen der Datei </translation>
    </message>
    <message>
        <location filename="../radio_controller.cpp" line="369"/>
        <source>RAW File</source>
        <translation>RAW Datei</translation>
    </message>
    <message>
        <location filename="../radio_controller.cpp" line="382"/>
        <location filename="../radio_controller.cpp" line="848"/>
        <source>Scanning</source>
        <translation>Scanne</translation>
    </message>
    <message>
        <location filename="../radio_controller.cpp" line="386"/>
        <location filename="../radio_controller.cpp" line="873"/>
        <source>Found channels</source>
        <translation>Gefundene Sender</translation>
    </message>
    <message>
        <location filename="../radio_controller.cpp" line="602"/>
        <source>Playing last station</source>
        <translation>Gebe zuletzt gehörten Sender wieder</translation>
    </message>
    <message>
        <source>Lost signal or bad signal quality, trying to find it again.</source>
        <translation type="vanished">Kein oder schlechter Empfang. Suche Sender neu.</translation>
    </message>
    <message>
        <location filename="../radio_controller.cpp" line="660"/>
        <source>Radio device is not ready or does not exist.</source>
        <translation>Gerät meldet einen Fehler oder existiert nicht.</translation>
    </message>
    <message>
        <source>Tuning</source>
        <translation type="vanished">Suche</translation>
    </message>
    <message>
        <location filename="../../input/airspy_sdr.cpp" line="152"/>
        <source>airspy is unplugged.</source>
        <translation>Airspy wurde entfernt.</translation>
    </message>
    <message>
        <location filename="../../input/input_factory.cpp" line="79"/>
        <source>No valid device found use Null device instead.</source>
        <translation type="unfinished">Kein Gerät gefunden, verwende Standardgerät.</translation>
    </message>
    <message>
        <location filename="../../input/input_factory.cpp" line="81"/>
        <location filename="../../input/input_factory.cpp" line="124"/>
        <source>Error while opening device</source>
        <translation>Fehler beim Öffnen des Geräts</translation>
    </message>
    <message>
        <location filename="../../input/raw_file.cpp" line="177"/>
        <location filename="../../input/raw_file.cpp" line="197"/>
        <source>Cannot open file </source>
        <translation type="unfinished">Kann Datei nicht öffnen </translation>
    </message>
    <message>
        <location filename="../../input/raw_file.cpp" line="310"/>
        <source>End of file, restarting</source>
        <translation>Datei ist zu Ende, beginne von vorn</translation>
    </message>
    <message>
        <location filename="../../input/raw_file.cpp" line="313"/>
        <source>End of file</source>
        <translation>Datei ist zu Ende</translation>
    </message>
    <message>
        <location filename="../../input/raw_file.cpp" line="401"/>
        <source>Unknown RAW file format</source>
        <translation>Unbekanntes RAW-Dateiformat</translation>
    </message>
    <message>
        <location filename="../../input/rtl_sdr.cpp" line="294"/>
        <location filename="../../input/rtl_tcp.cpp" line="462"/>
        <source>ADC overload. Maybe you are using a too high gain.</source>
        <translation type="unfinished">ADC überlastet. Evtl. Verstärkung zu stark.</translation>
    </message>
    <message>
        <location filename="../../input/rtl_sdr.cpp" line="390"/>
        <source>RTL-SDR is unplugged.</source>
        <translation>RTL-SDR wurde entfernt.</translation>
    </message>
    <message>
        <location filename="../../input/rtl_tcp.cpp" line="272"/>
        <source>RTL-TCP connection closed.</source>
        <translation>RTL-TCP-Verbindung wurde geschlossen.</translation>
    </message>
    <message>
        <location filename="../../input/rtl_tcp.cpp" line="413"/>
        <source>Connection failed to server </source>
        <translation>Verbindungsfehler zu Server </translation>
    </message>
    <message>
        <location filename="../../input/soapy_sdr.cpp" line="91"/>
        <source>Could not load SoapySDR with provided device arguments.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChannelBrowser</name>
    <message>
        <location filename="../src/gui/QML/ChannelBrowser.qml" line="289"/>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Found channels</source>
        <translation type="obsolete">Gefundene Sender</translation>
    </message>
    <message>
        <source>Automatic RF gain</source>
        <translation type="obsolete">Auto HF-Verstärkung</translation>
    </message>
    <message>
        <source>Manual gain</source>
        <translation type="obsolete">Manuelle Verstärkung</translation>
    </message>
    <message>
        <source>Value: </source>
        <translation type="obsolete">Aktuell: </translation>
    </message>
    <message>
        <source>Select channel manually</source>
        <translation type="obsolete">Manuelle Kanalwahl</translation>
    </message>
    <message>
        <source>Clear station list</source>
        <translation type="obsolete">Lösche Senderliste</translation>
    </message>
    <message>
        <source>Full screen mode</source>
        <translation type="obsolete">Vollbildmodus</translation>
    </message>
    <message>
        <source>Expert mode</source>
        <translation type="obsolete">Expertenmodus</translation>
    </message>
    <message>
        <source>Exit welle.io</source>
        <translation type="obsolete">welle.io beenden</translation>
    </message>
</context>
<context>
    <name>ChannelSettings</name>
    <message>
        <location filename="../QML/settingpages/ChannelSettings.qml" line="29"/>
        <source>Automatic start playing last station</source>
        <translation type="unfinished">Zuletzt gehörten Sender wiedergeben</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/ChannelSettings.qml" line="36"/>
        <source>Display station name in the window title</source>
        <translation type="unfinished">Zeige Stationsnamen im Titelfenster</translation>
    </message>
</context>
<context>
    <name>ConstellationGraph</name>
    <message>
        <location filename="../QML/expertviews/ConstellationGraph.qml" line="10"/>
        <source>Constellation Diagram</source>
        <translation>Konstellationsdiagramm</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/ConstellationGraph.qml" line="40"/>
        <source>DQPSK Angle [Degree]</source>
        <translation>DQPSK Winkel [Grad]</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/ConstellationGraph.qml" line="47"/>
        <source>Subcarrier</source>
        <translation>Unterträger</translation>
    </message>
</context>
<context>
    <name>DABConstants</name>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="184"/>
        <source>News</source>
        <translation>Nachrichten</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="185"/>
        <source>Current Affairs</source>
        <translation type="unfinished">Aktuelle Info</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="186"/>
        <source>Information</source>
        <translation type="unfinished">Service_Programm</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="187"/>
        <source>Sport</source>
        <translation>Sport</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="188"/>
        <source>Education</source>
        <translation>Bildung</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="189"/>
        <source>Drama</source>
        <translation type="unfinished">Hörspiel + Lit</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="190"/>
        <source>Arts</source>
        <translation type="unfinished">Kultur + Gesellsch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="191"/>
        <source>Science</source>
        <translation type="unfinished">Wissenschaft</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="192"/>
        <source>Talk</source>
        <translation type="unfinished">Talk</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="193"/>
        <source>Pop Music</source>
        <translation type="unfinished">Pop Musik</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="194"/>
        <source>Rock Music</source>
        <translation type="unfinished">Rock Musik</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="195"/>
        <source>Easy Listening</source>
        <translation type="unfinished">Unterhalt Musik</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="196"/>
        <source>Light classical</source>
        <translation type="unfinished">Leichte Klassik</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="197"/>
        <source>Classical Music</source>
        <translation type="unfinished">Ernste Klassik</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="198"/>
        <source>Other Music</source>
        <translation type="unfinished">Spezielle Musik</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="199"/>
        <source>Weather</source>
        <translation>Wetter</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="200"/>
        <source>Finance</source>
        <translation type="unfinished">Wirtschaft</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="201"/>
        <source>Children&apos;s</source>
        <translation type="unfinished">Kinderprogramm</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="202"/>
        <source>Factual</source>
        <translation type="unfinished">Sozialwesen</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="203"/>
        <source>Religion</source>
        <translation>Religion</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="204"/>
        <source>Phone In</source>
        <translation type="unfinished">Anrufsendung</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="205"/>
        <source>Travel</source>
        <translation type="unfinished">Reiseinformation</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="206"/>
        <source>Leisure</source>
        <translation>Freizeit</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="207"/>
        <source>Jazz and Blues</source>
        <translation type="unfinished">Jazz</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="208"/>
        <source>Country Music</source>
        <translation type="unfinished">Country Musik</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="209"/>
        <source>National Music</source>
        <translation type="unfinished">Landesmusik</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="210"/>
        <source>Oldies Music</source>
        <translation type="unfinished">Oldies Musik</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="211"/>
        <source>Folk Music</source>
        <translation type="unfinished">Folklore</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="212"/>
        <source>Documentary</source>
        <translation type="unfinished">Feature</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="213"/>
        <source>entry 30 not used</source>
        <translation>Eintrag 30 nicht verwendet</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="214"/>
        <source>entry 31 not used</source>
        <translation>Eintrag 31 nicht verwendet</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="215"/>
        <location filename="../../backend/dab-constants.cpp" line="332"/>
        <source>UNKNOWN</source>
        <translation>UNBEKANNT</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="229"/>
        <source>Albanian</source>
        <translation>Albanisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="230"/>
        <source>Breton</source>
        <translation>Bretonisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="231"/>
        <source>Catalan</source>
        <translation>Katalanisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="232"/>
        <source>Croatian</source>
        <translation>Kroatisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="233"/>
        <source>Welsh</source>
        <translation>Wallisisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="234"/>
        <source>Czech</source>
        <translation>Tschechisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="235"/>
        <source>Danish</source>
        <translation>Dänisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="236"/>
        <source>German</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="237"/>
        <source>English</source>
        <translation>Englisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="238"/>
        <source>Spanish</source>
        <translation>Spanisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="239"/>
        <source>Esperanto</source>
        <translation>Esperanto</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="240"/>
        <source>Estonian</source>
        <translation>Estnisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="241"/>
        <source>Basque</source>
        <translation>Baskisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="242"/>
        <source>Faroese</source>
        <translation>Färöisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="243"/>
        <source>French</source>
        <translation>Französisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="244"/>
        <source>Frisian</source>
        <translation>Friesisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="245"/>
        <source>Irish</source>
        <translation>Irisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="246"/>
        <source>Gaelic</source>
        <translation>Gälisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="247"/>
        <source>Galician</source>
        <translation>Galizisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="248"/>
        <source>Icelandic</source>
        <translation>Isländisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="249"/>
        <source>Italian</source>
        <translation>Italienisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="250"/>
        <source>Lappish</source>
        <translation>Lappländisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="251"/>
        <source>Latin</source>
        <translation>Latein</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="252"/>
        <source>Latvian</source>
        <translation>Lettisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="253"/>
        <source>Luxembourgian</source>
        <translation>Luxemburgisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="254"/>
        <source>Lithuanian</source>
        <translation>Litauisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="255"/>
        <source>Hungarian</source>
        <translation>Ungarisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="256"/>
        <source>Maltese</source>
        <translation>Maltesisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="257"/>
        <source>Dutch</source>
        <translation>Niederländisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="258"/>
        <source>Norwegian</source>
        <translation>Norwegisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="259"/>
        <source>Occitan</source>
        <translation>Provenzalisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="260"/>
        <source>Polish</source>
        <translation>Polnisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="261"/>
        <source>Portuguese</source>
        <translation>Portugiesisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="262"/>
        <source>Romanian</source>
        <translation>Rumänisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="263"/>
        <source>Romansh</source>
        <translation>Rätoromanisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="264"/>
        <source>Serbian</source>
        <translation>Serbisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="265"/>
        <source>Slovak</source>
        <translation>Slowakisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="266"/>
        <source>Slovene</source>
        <translation>Slowenisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="267"/>
        <source>Finnish</source>
        <translation>Finnisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="268"/>
        <source>Swedish</source>
        <translation>Schwedisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="269"/>
        <source>Turkish</source>
        <translation>Türkisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="270"/>
        <source>Flemish</source>
        <translation>Flämisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="271"/>
        <source>Walloon</source>
        <translation>Wallonisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="272"/>
        <source>Background sound/clean feed</source>
        <translation type="unfinished">Hintergrundaudio/Original</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="273"/>
        <source>Zulu</source>
        <translation>Zulu</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="274"/>
        <source>Vietnamese</source>
        <translation>Vietnamesisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="275"/>
        <source>Uzbek</source>
        <translation>Usbekisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="276"/>
        <source>Urdu</source>
        <translation>Urdu</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="277"/>
        <source>Ukranian</source>
        <translation>Ukrainisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="278"/>
        <source>Thai</source>
        <translation>Thailändisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="279"/>
        <source>Telugu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="280"/>
        <source>Tatar</source>
        <translation>Tatarisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="281"/>
        <source>Tamil</source>
        <translation>Tamil</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="282"/>
        <source>Tadzhik</source>
        <translation>Tadschikisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="283"/>
        <source>Swahili</source>
        <translation>Suaheli</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="284"/>
        <source>Sranan Tongo</source>
        <translation>Sranan Tongo</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="285"/>
        <source>Somali</source>
        <translation>Somalisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="286"/>
        <source>Sinhalese</source>
        <translation>Singhalesisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="287"/>
        <source>Shona</source>
        <translation>Shona</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="288"/>
        <source>Serbo-Croat</source>
        <translation>Serbo-Kroatisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="289"/>
        <source>Rusyn</source>
        <translation>Ruthenisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="290"/>
        <source>Russian</source>
        <translation>Russisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="291"/>
        <source>Quechua</source>
        <translation>Ketschua</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="292"/>
        <source>Pushtu</source>
        <translation>Paschtunisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="293"/>
        <source>Punjabi</source>
        <translation>Pandschabisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="294"/>
        <source>Persian</source>
        <translation>Persisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="295"/>
        <source>Papiamento</source>
        <translation>Papiamento</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="296"/>
        <source>Oriya</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="297"/>
        <source>Nepali</source>
        <translation>Napalesisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="298"/>
        <source>Ndebele</source>
        <translation>Ndebele</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="299"/>
        <source>Marathi</source>
        <translation>Marathi</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="300"/>
        <source>Moldavian</source>
        <translation>Moldawisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="301"/>
        <source>Malaysian</source>
        <translation>Malaysisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="302"/>
        <source>Malagasay</source>
        <translation>Madagassisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="303"/>
        <source>Macedonian</source>
        <translation>Mazedonisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="304"/>
        <source>Laotian</source>
        <translation>Laotisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="305"/>
        <source>Korean</source>
        <translation>Koreanisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="306"/>
        <source>Khmer</source>
        <translation>Khmer</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="307"/>
        <source>Kazakh</source>
        <translation>Kasachisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="308"/>
        <source>Kannada</source>
        <translation type="unfinished">Kannada</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="309"/>
        <source>Japanese</source>
        <translation>Japanisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="310"/>
        <source>Indonesian</source>
        <translation>Indonesisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="311"/>
        <source>Hindi</source>
        <translation>Hindi</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="312"/>
        <source>Hebrew</source>
        <translation>Hebräisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="313"/>
        <source>Hausa</source>
        <translation>Hausa</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="314"/>
        <source>Gurani</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="315"/>
        <source>Gujurati</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="316"/>
        <source>Greek</source>
        <translation>Griechisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="317"/>
        <source>Georgian</source>
        <translation>Georgisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="318"/>
        <source>Fulani</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="319"/>
        <source>Dari</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="320"/>
        <source>Chuvash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="321"/>
        <source>Chinese</source>
        <translation>Chinesisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="322"/>
        <source>Burmese</source>
        <translation>Burmesisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="323"/>
        <source>Bulgarian</source>
        <translation>Bulgarisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="324"/>
        <source>Bengali</source>
        <translation>Bengali</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="325"/>
        <source>Belorussian</source>
        <translation>Weißrussisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="326"/>
        <source>Bambora</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="327"/>
        <source>Azerbaijani</source>
        <translation>Aserbeidschanisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="328"/>
        <source>Assamese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="329"/>
        <source>Armenian</source>
        <translation>Armenisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="330"/>
        <source>Arabic</source>
        <translation>Arabisch</translation>
    </message>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="331"/>
        <source>Amharic</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExpertSettings</name>
    <message>
        <location filename="../QML/settingpages/ExpertSettings.qml" line="33"/>
        <source>Global</source>
        <translation type="unfinished">Allgemein</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/ExpertSettings.qml" line="37"/>
        <source>Expert mode</source>
        <translation>Expertenmodus</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/ExpertSettings.qml" line="43"/>
        <source>Backend</source>
        <translation type="unfinished">Signalverarbeitung</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/ExpertSettings.qml" line="50"/>
        <source>Enable coarse corrector (for receivers with &gt;1kHz error)</source>
        <translation type="unfinished">Grobe Korrektur aktivieren (für Geräte mit &gt;1kHz Fehler)</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/ExpertSettings.qml" line="65"/>
        <source>GetMiddle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../QML/settingpages/ExpertSettings.qml" line="65"/>
        <source>CorrelatePRS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../QML/settingpages/ExpertSettings.qml" line="65"/>
        <source>PatternOfZeros</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../QML/settingpages/ExpertSettings.qml" line="75"/>
        <source>Coarse corrector algorithm</source>
        <translation type="unfinished">Algorithmus für Grobe Korrektur</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/ExpertSettings.qml" line="83"/>
        <source>Enable TII decoding to console log (increases CPU usage)</source>
        <translation type="unfinished">TII-Dekoder-Log auf der Konsole aktivieren (erhöht die CPU-Last)</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/ExpertSettings.qml" line="97"/>
        <source>Strongest Peak</source>
        <translation type="unfinished">Größter Spitzenwert</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/ExpertSettings.qml" line="97"/>
        <source>Earliest Peak With Binning</source>
        <translation type="unfinished">Frühester Spitzenwert mit Binning</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/ExpertSettings.qml" line="97"/>
        <source>Threshold Before Peak</source>
        <translation type="unfinished">Schwelle vor dem Spitzenwert</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/ExpertSettings.qml" line="107"/>
        <source>FFT Window placement algorithm</source>
        <translation type="unfinished">Algorithmus für FFT Fensterposition</translation>
    </message>
</context>
<context>
    <name>ExpertView</name>
    <message>
        <source>Device</source>
        <translation type="vanished">Radioempfänger</translation>
    </message>
    <message>
        <source>Current channel</source>
        <translation type="vanished">Aktueller Kanal</translation>
    </message>
    <message>
        <source>Frequency correction</source>
        <translation type="vanished">Frequenzkorrektur</translation>
    </message>
    <message>
        <source>SNR</source>
        <translation type="vanished">SNR</translation>
    </message>
    <message>
        <source>Frame errors</source>
        <translation type="vanished">Framefehler</translation>
    </message>
    <message>
        <source>RS errors</source>
        <translation type="vanished">RS Fehler</translation>
    </message>
    <message>
        <source>AAC errors</source>
        <translation type="vanished">AAC Framefehler</translation>
    </message>
    <message>
        <source>Frame synchronization</source>
        <translation type="vanished">Synchronisation</translation>
    </message>
    <message>
        <source>FIC CRC</source>
        <translation type="vanished">FIC CRC</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="vanished">OK</translation>
    </message>
    <message>
        <source>Not synced</source>
        <translation type="vanished">Nicht synchron</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Fehler</translation>
    </message>
</context>
<context>
    <name>GlobalSettings</name>
    <message>
        <location filename="../QML/settingpages/GlobalSettings.qml" line="68"/>
        <source>Global settings</source>
        <translation type="unfinished">Allgemeine Einstellungen</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/GlobalSettings.qml" line="72"/>
        <source>Full screen mode</source>
        <translation>Vollbildmodus</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/GlobalSettings.qml" line="103"/>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <source>Qt Quick Style. Restart to apply.</source>
        <translation type="obsolete">Stil von Qt Quick. Neustarten zum Übernehmen.</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/GlobalSettings.qml" line="110"/>
        <source>Global receiver settings</source>
        <translation>Allgemeine Geräteeinstellungen</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/GlobalSettings.qml" line="114"/>
        <source>Automatic RF gain</source>
        <translation>Automatische HF-Verstärkung</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/GlobalSettings.qml" line="134"/>
        <source>Manual gain</source>
        <translation>Manuelle Verstärkung</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/GlobalSettings.qml" line="140"/>
        <source>Value: </source>
        <translation type="unfinished">Wert: </translation>
    </message>
    <message>
        <location filename="../QML/settingpages/GlobalSettings.qml" line="165"/>
        <source>Auto detect</source>
        <translation type="unfinished">Automatische Erkennung</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/GlobalSettings.qml" line="211"/>
        <source>Style settings</source>
        <translation type="unfinished">Stileinstellungen</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/GlobalSettings.qml" line="223"/>
        <source>Style changed. Please restart welle.io</source>
        <translation type="unfinished">Stil geändert. Bitte welle.io neu starten</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/GlobalSettings.qml" line="228"/>
        <source>Style. Restart to apply.</source>
        <translation type="unfinished">Stil. Neustarten zum Übernehmen.</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/GlobalSettings.qml" line="241"/>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../QML/settingpages/GlobalSettings.qml" line="242"/>
        <source>Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../QML/settingpages/GlobalSettings.qml" line="243"/>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../QML/settingpages/GlobalSettings.qml" line="247"/>
        <source>Theme</source>
        <translation type="unfinished">Thema</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">Kein</translation>
    </message>
    <message>
        <source>Airspy</source>
        <translation type="obsolete">Airspy</translation>
    </message>
    <message>
        <source>rtl-sdr</source>
        <translation type="obsolete">rtl-sdr</translation>
    </message>
    <message>
        <source>SoapySDR</source>
        <translation type="obsolete">SoapySDR</translation>
    </message>
    <message>
        <source>rtl-tcp</source>
        <translation type="obsolete">rtl-tcp</translation>
    </message>
    <message>
        <source>RAW file</source>
        <translation type="obsolete">RAW Datei</translation>
    </message>
</context>
<context>
    <name>ImpulseResponseGraph</name>
    <message>
        <location filename="../QML/expertviews/ImpulseResponseGraph.qml" line="12"/>
        <source>Impulse Response</source>
        <translation type="unfinished">Impulsantwort</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/ImpulseResponseGraph.qml" line="23"/>
        <source>Amplitude</source>
        <translation type="unfinished">Amplitude</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/ImpulseResponseGraph.qml" line="24"/>
        <source>Samples</source>
        <translation type="unfinished">Abtastwerte</translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../QML/MainView.qml" line="172"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="180"/>
        <source>Expert Settings</source>
        <translation>Experteneinstellungen</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="188"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="196"/>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="234"/>
        <source>All stations</source>
        <translation type="unfinished">Alle Sender</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="234"/>
        <source>Favorites</source>
        <translation>Favoriten</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="263"/>
        <source>Start station scan</source>
        <translation>Suchlauf starten</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="275"/>
        <source>Stop station scan</source>
        <translation>Suchlauf stoppen</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="287"/>
        <source>Clear station list</source>
        <translation type="unfinished">Lösche Senderliste</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="295"/>
        <source>Station settings</source>
        <translation type="unfinished">Sendereinstellungen</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="308"/>
        <source>No stations in list</source>
        <translation type="unfinished">Kein Sender in der Liste</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="345"/>
        <source>Manual channel</source>
        <translation type="unfinished">Manueller Kanal</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="400"/>
        <source>Service Overview</source>
        <translation type="unfinished">Senderübersicht</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="406"/>
        <source>Service Details</source>
        <translation type="unfinished">Senderdetails</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="412"/>
        <source>MOT Slide Show</source>
        <translation type="unfinished">MOT Slideshow</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="418"/>
        <source>Spectrum</source>
        <translation>Spektrum</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="424"/>
        <source>Impulse Response</source>
        <translation type="unfinished">Impulsantwort</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="430"/>
        <source>Constellation Diagram</source>
        <translation>Konstellationsdiagramm</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="436"/>
        <source>Null Symbol</source>
        <translation>Nullsymbol</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="442"/>
        <source>Console Output</source>
        <translation>Konsolenausgabe</translation>
    </message>
    <message>
        <location filename="../QML/MainView.qml" line="448"/>
        <source>RAW Recorder</source>
        <translation type="unfinished">RAW-Aufzeichnung</translation>
    </message>
</context>
<context>
    <name>MotView</name>
    <message>
        <location filename="../QML/MotView.qml" line="10"/>
        <source>MOT Slide Show</source>
        <translation type="unfinished">MOT Slideshow</translation>
    </message>
    <message>
        <location filename="../QML/MotView.qml" line="27"/>
        <source>Save all images</source>
        <translation type="unfinished">Alle Bilder speichern</translation>
    </message>
    <message>
        <location filename="../QML/MotView.qml" line="47"/>
        <source>Latest</source>
        <translation type="unfinished">Letztes</translation>
    </message>
</context>
<context>
    <name>NullSymbolGraph</name>
    <message>
        <location filename="../QML/expertviews/NullSymbolGraph.qml" line="10"/>
        <source>Null Symbol</source>
        <translation type="unfinished">Nullsymbol</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/NullSymbolGraph.qml" line="18"/>
        <source>Amplitude</source>
        <translation>Amplitude</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation type="obsolete">Frequenz</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>No valid device found, using Null device instead.</source>
        <translation type="vanished">Kein Radioempfänger gefunden.</translation>
    </message>
    <message>
        <source>Error while opening device</source>
        <translation type="vanished">Fehler beim Zugriff auf Empfänger</translation>
    </message>
    <message>
        <source>Unknown RAW file format</source>
        <translation type="vanished">Unbekanntes RAW-Dateiformat</translation>
    </message>
    <message>
        <source>Cannot open file</source>
        <translation type="vanished">Fehler beim Öffnen der Datei</translation>
    </message>
    <message>
        <source>End of file, restarting</source>
        <translation type="vanished">RAW-Datei zu Ende, beginne von vorn</translation>
    </message>
    <message>
        <source>AGC overload. Maybe you are using a to high gain.</source>
        <translation type="obsolete">HF-Eingangsverstärkung ist zu groß (AGC ist übersteuert).</translation>
    </message>
    <message>
        <source>RTL-SDR is unplugged.</source>
        <translation type="vanished">RTL-SDR wurde entfernt.</translation>
    </message>
    <message>
        <source>RTL-TCP connection closed.</source>
        <translation type="vanished">RTL-TCP-Versbindung geschlossen.</translation>
    </message>
    <message>
        <source>Connection failed to server </source>
        <translation type="vanished">Verbindungsfehler zu Server </translation>
    </message>
</context>
<context>
    <name>RTLSDRSettings</name>
    <message>
        <location filename="../QML/settingpages/RTLSDRSettings.qml" line="12"/>
        <source>rtl-sdr settings</source>
        <translation type="unfinished">rtl-sdr Einstellungen</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/RTLSDRSettings.qml" line="21"/>
        <source>Enable bias tee (not from all dongles supported)</source>
        <translation type="unfinished">Fernspeisung aktivieren (nicht von allen Geräten unterstützt)</translation>
    </message>
</context>
<context>
    <name>RTLTCPSettings</name>
    <message>
        <location filename="../QML/settingpages/RTLTCPSettings.qml" line="11"/>
        <source>rtl-tcp settings</source>
        <translation type="unfinished">rtl-tcp Einstellungen</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/RTLTCPSettings.qml" line="27"/>
        <source>Use host name</source>
        <translation type="unfinished">Verwende Hostnamen</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/RTLTCPSettings.qml" line="37"/>
        <source>IP address</source>
        <translation>IP-Adresse</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/RTLTCPSettings.qml" line="68"/>
        <source>IP port</source>
        <translation type="unfinished">IP-Port</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/RTLTCPSettings.qml" line="84"/>
        <source>Enter host name</source>
        <translation type="unfinished">Hostnamen eingeben</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/RTLTCPSettings.qml" line="88"/>
        <source>Host name</source>
        <translation type="unfinished">Hostname</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="obsolete">Übernehmen</translation>
    </message>
</context>
<context>
    <name>RadioView</name>
    <message>
        <location filename="../QML/RadioView.qml" line="12"/>
        <source>Service Overview</source>
        <translation type="unfinished">Senderübersicht</translation>
    </message>
</context>
<context>
    <name>RawFileSettings</name>
    <message>
        <location filename="../QML/settingpages/RawFileSettings.qml" line="12"/>
        <source>RAW file settings</source>
        <translation type="unfinished">Einstellungen für Rohdaten</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/RawFileSettings.qml" line="39"/>
        <source>Open RAW file</source>
        <translation>Öffne Rohdatendatei</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/RawFileSettings.qml" line="43"/>
        <source>Currently shown under Android</source>
        <translation type="unfinished">Derzeit unter Android angezeigt</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/RawFileSettings.qml" line="62"/>
        <source>Selected file:</source>
        <translation>Ausgewählte Datei:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="vanished">Übernehmen</translation>
    </message>
</context>
<context>
    <name>RawRecorder</name>
    <message>
        <location filename="../QML/expertviews/RawRecorder.qml" line="11"/>
        <source>I/Q RAW Recorder (experimental)</source>
        <translation>Rohdaten (I/O) aufnehmen (experimentell)</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/RawRecorder.qml" line="19"/>
        <source>Ring buffer length [s]</source>
        <translation type="unfinished">Ringpufferlänge [s]</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/RawRecorder.qml" line="33"/>
        <source>Save ring buffer</source>
        <translation type="unfinished">Ringpuffer speichern</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/RawRecorder.qml" line="33"/>
        <source>Init</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../QML/expertviews/RawRecorder.qml" line="47"/>
        <source>Ring buffer size (roughly): </source>
        <translation type="unfinished">Ringpuffergröße (ca.): </translation>
    </message>
</context>
<context>
    <name>ServiceDetails</name>
    <message>
        <location filename="../QML/expertviews/ServiceDetails.qml" line="10"/>
        <source>Service Details</source>
        <translation type="unfinished">Senderdetails</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/ServiceDetails.qml" line="17"/>
        <source>Device</source>
        <translation type="unfinished">Gerät</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/ServiceDetails.qml" line="22"/>
        <source>Current channel</source>
        <translation type="unfinished">Aktueller Kanal</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/ServiceDetails.qml" line="35"/>
        <source>Frame sync</source>
        <translation type="unfinished">Framesynchron</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/ServiceDetails.qml" line="50"/>
        <source>FIC CRC</source>
        <translation type="unfinished">FIC CRC</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/ServiceDetails.qml" line="66"/>
        <source>Frame errors</source>
        <translation type="unfinished">Framefehler</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/ServiceDetails.qml" line="36"/>
        <location filename="../QML/expertviews/ServiceDetails.qml" line="51"/>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/ServiceDetails.qml" line="36"/>
        <source>Not synced</source>
        <translation type="unfinished">Nicht synchron</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/ServiceDetails.qml" line="51"/>
        <source>Error</source>
        <translation type="unfinished">Fehler</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/ServiceDetails.qml" line="72"/>
        <source>Frequency correction</source>
        <translation type="unfinished">Frequenzkorrektur</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/ServiceDetails.qml" line="77"/>
        <source>SNR</source>
        <translation type="unfinished">SNR</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/ServiceDetails.qml" line="82"/>
        <source>RS errors</source>
        <translation type="unfinished">RS Fehler</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/ServiceDetails.qml" line="87"/>
        <source>AAC errors</source>
        <translation type="unfinished">AAC Fehler</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/ServiceDetails.qml" line="92"/>
        <source>DAB date and time</source>
        <translation type="unfinished">DAB Datum/Uhrzeit</translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Channel scan</source>
        <translation type="vanished">Sendersuchlauf</translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="vanished">Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="vanished">Stopp</translation>
    </message>
    <message>
        <source>Found channels</source>
        <translation type="vanished">Gefundene Sender</translation>
    </message>
    <message>
        <source>Found stations</source>
        <translation type="vanished">Gefundene Programme</translation>
    </message>
    <message>
        <source>Automatic RF gain</source>
        <translation type="vanished">Auto HF-Verstärkung</translation>
    </message>
    <message>
        <source>Manual gain</source>
        <translation type="vanished">Manuelle Verstärkung</translation>
    </message>
    <message>
        <source>Value: </source>
        <translation type="vanished">Aktuell: </translation>
    </message>
    <message>
        <source>Full screen mode</source>
        <translation type="vanished">Vollbildmodus</translation>
    </message>
    <message>
        <source>Expert mode</source>
        <translation type="vanished">Expertenmodus</translation>
    </message>
    <message>
        <source>Select channel manually</source>
        <translation type="vanished">Manuelle Kanalwahl</translation>
    </message>
    <message>
        <source>Clear station list</source>
        <translation type="vanished">Lösche Senderliste</translation>
    </message>
    <message>
        <source>Exit welle.io</source>
        <translation type="vanished">welle.io beenden</translation>
    </message>
</context>
<context>
    <name>SoapySDRSettings</name>
    <message>
        <location filename="../QML/settingpages/SoapySDRSettings.qml" line="11"/>
        <source>SoapySDR settings</source>
        <translation>SoapySDR Einstellungen</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/SoapySDRSettings.qml" line="24"/>
        <source>Antenna</source>
        <translation>Antenne</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/SoapySDRSettings.qml" line="30"/>
        <source>Enter antenna</source>
        <translation type="unfinished">Antenne eingeben</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/SoapySDRSettings.qml" line="36"/>
        <source>Clock source</source>
        <translation type="unfinished">Taktquelle</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/SoapySDRSettings.qml" line="42"/>
        <source>Enter clock source</source>
        <translation type="unfinished">Taktquelle eingeben</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/SoapySDRSettings.qml" line="48"/>
        <source>Driver arguments</source>
        <translation type="unfinished">Treiberargumente</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/SoapySDRSettings.qml" line="54"/>
        <source>Enter driver arguments</source>
        <translation type="unfinished">Treiberargumente eingeben</translation>
    </message>
    <message>
        <location filename="../QML/settingpages/SoapySDRSettings.qml" line="60"/>
        <source>Apply</source>
        <translation>Übernehmen</translation>
    </message>
</context>
<context>
    <name>SpectrumGraph</name>
    <message>
        <location filename="../QML/expertviews/SpectrumGraph.qml" line="12"/>
        <source>Spectrum</source>
        <translation>Spektrum</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/SpectrumGraph.qml" line="21"/>
        <source>Amplitude</source>
        <translation>Amplitude</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation type="obsolete">Frequenz</translation>
    </message>
</context>
<context>
    <name>SpectrumView</name>
    <message>
        <source>Spectrum</source>
        <translation type="vanished">Spektrum</translation>
    </message>
    <message>
        <source>Amplitude</source>
        <translation type="vanished">Amplitude</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation type="vanished">Frequenz</translation>
    </message>
</context>
<context>
    <name>TextOutputView</name>
    <message>
        <location filename="../QML/expertviews/TextOutputView.qml" line="11"/>
        <source>Console Output</source>
        <translation>Konsolenausgabe</translation>
    </message>
    <message>
        <location filename="../QML/expertviews/TextOutputView.qml" line="69"/>
        <source>Warning: The console view can slow down the complete app!</source>
        <translation type="unfinished">Warnung: Die Konsolenausgabe kann welle.io verlangsamen!</translation>
    </message>
</context>
<context>
    <name>TouchSwitch</name>
    <message>
        <source>ON</source>
        <translation type="vanished">AN</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation type="vanished">AUS</translation>
    </message>
</context>
<context>
    <name>ViewBaseFrame</name>
    <message>
        <location filename="../QML/components/ViewBaseFrame.qml" line="122"/>
        <source>Minimize</source>
        <translation type="unfinished">Minimieren</translation>
    </message>
    <message>
        <location filename="../QML/components/ViewBaseFrame.qml" line="122"/>
        <source>Maximize</source>
        <translation type="unfinished">Maximieren</translation>
    </message>
    <message>
        <location filename="../QML/components/ViewBaseFrame.qml" line="131"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
</context>
<context>
    <name>WDialog</name>
    <message>
        <location filename="../QML/components/WDialog.qml" line="32"/>
        <source>‹</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WSpectrum</name>
    <message>
        <location filename="../QML/components/WSpectrum.qml" line="15"/>
        <source>Amplitude</source>
        <translation>Amplitude</translation>
    </message>
    <message>
        <location filename="../QML/components/WSpectrum.qml" line="16"/>
        <source>Frequency</source>
        <translation>Frequenz</translation>
    </message>
    <message>
        <location filename="../QML/components/WSpectrum.qml" line="39"/>
        <source>Waterfall</source>
        <translation>Wasserfall</translation>
    </message>
    <message>
        <location filename="../QML/components/WSpectrum.qml" line="39"/>
        <source>experimental</source>
        <translation>experimentell</translation>
    </message>
    <message>
        <location filename="../QML/components/WSpectrum.qml" line="101"/>
        <source>Sensitivity</source>
        <translation>Empfindlichkeit</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Set the GUI language (e.g. de-DE)</source>
        <translation type="vanished">GUI Sprache festlegen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="100"/>
        <source>Records DAB frames (*.mp2) or DAB+ superframes with RS coding (*.dab). This file can be used to analyse X-PAD data with XPADxpert</source>
        <translation type="unfinished">Speichert DAB Frames (*.mp2) oder DAB+ Superframes mit RS Kodierung (*.dab). Diese Datei kann zur Analyse der X-PAD-Daten in XPADxpert verwendet werden</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="101"/>
        <location filename="../main.cpp" line="106"/>
        <source>File name</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="105"/>
        <source>Redirects all log output texts to a file.</source>
        <translation type="unfinished">Leitet alle Log-Meldungen in eine Datei um.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="110"/>
        <source>Qt Quick Controls Style for the 1st launch</source>
        <translation type="unfinished">Qt Quick Controls Vorlage für den ersten Start</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="111"/>
        <source>style_name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the GUI language according to the ISO country codes (e.g. de_DE)</source>
        <translation type="vanished">GUI-Sprache gemäß ISO Ländercode setzen (zB de_DE)</translation>
    </message>
    <message>
        <source>Language</source>
        <translation type="vanished">Sprache</translation>
    </message>
    <message>
        <source>Input device</source>
        <translation type="vanished">Radioempfänger</translation>
    </message>
    <message>
        <source>Input device. Possible is: auto (default), airspy, rtl_tcp, rtl_sdr, rawfile, soapysdr</source>
        <translation type="vanished">Radioempfänger. Möglich ist auto (Standard), airspy, rtl_tcp, rtl_sdr, rawfile, soapysdr</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="vanished">Name</translation>
    </message>
    <message>
        <source>DAB mode. Possible is: 1, 2 or 4, default: 1</source>
        <translation type="vanished">DAB Mode. Möglich ist 1, 2 oder 4, Standard: 1</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation type="vanished">Modus</translation>
    </message>
    <message>
        <source>rtl_tcp server IP address. Only valid for input rtl_tcp.</source>
        <translation type="vanished">rtl_tcp server IP Adresse. Nur gültig für Empfänger rtl_tcp.</translation>
    </message>
    <message>
        <source>IP address</source>
        <translation type="vanished">IP-Adresse</translation>
    </message>
    <message>
        <source>rtl_tcp server IP port. Only valid for input rtl_tcp.</source>
        <translation type="vanished">IP Port. Nur gültig für Empfänger rtl_tcp.</translation>
    </message>
    <message>
        <source>Port</source>
        <translation type="vanished">Port</translation>
    </message>
    <message>
        <source>I/Q RAW file. Only valid for input rawfile.</source>
        <translation type="vanished">I/Q RAW Datei als Radioempfänger. Nur gültig für Empfänger rawfile.</translation>
    </message>
    <message>
        <source>I/Q RAW file</source>
        <translation type="vanished">I/Q RAW Rohdatei</translation>
    </message>
    <message>
        <source>I/Q RAW file format. Possible is: u8 (standard), s8, s16le, s16be. Only valid for input rawfile.</source>
        <translation type="vanished">I/Q RAW Rohdateiformat. Möglich ist u8 (Standard), s8, s16le, s16be. Nur gültig für Radioempfänger rawfile.</translation>
    </message>
    <message>
        <source>I/Q RAW file format</source>
        <translation type="vanished">I/Q RAW Rohdatenformat</translation>
    </message>
    <message>
        <source>Expert mode is enabled</source>
        <translation type="vanished">Expertenmodus eingeschaltet</translation>
    </message>
    <message>
        <source>Expert mode is disabled</source>
        <translation type="vanished">Expertenmodus ausgeschaltet</translation>
    </message>
</context>
</TS>
